@@ -3,6 +3,12 @@ from ScraGet.project import get_project
 from ScraGet.studios import get_studio
 from ScraGet.user import get_user, get_user_extra
 from ScraGet.frontpage import get_frontpage
+from ScraGet.encoder import encoder
 from ScraGet import ScraGet
 
-print("ScraGet: https://github.com/Quantum-Codes/ScraGet")
\ No newline at end of file
+print("ScraGet: https://github.com/Quantum-Codes/ScraGet")
+
+"""
+ScraGet - A package used to make it easier to get data from the Scratch API.
+Wiki: https://github.com/Quantum-Codes/ScraGet/wiki
+"""
\ No newline at end of file
